#!/bin/bash

#    YAATOBS - yet another arm toolchain build script
# 
#    Copyright (C) 2019  Torsten Brischalle
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/

set -e

. ./00_settings.sh

GDB_FLAGS="--prefix=${TOOLCHAIN_PREFIX} --target=${TOOLCHAIN_TARGET} --enable-interwork --enable-multilib --disable-werror"

echo "*****************************************************"
echo "*** build gdb                                     ***"
echo "*****************************************************"

cd tmp

rm -rf gdb-*-build
mkdir gdb-${GDB_VERSION}-build

if [ -d gdb-${GDB_VERSION} ]
then
  echo "gdb already extracted"
else
  if [ -e ../sources/gdb-${GDB_VERSION}.tar.gz ]
  then
    echo "gdb already downloaded"
  else
    echo "download gdb"
    wget ${WGET_OPT} -P ../sources https://ftpmirror.gnu.org/gdb/gdb-${GDB_VERSION}.tar.gz
  fi

  echo "extract gdb"
  tar -xzf ../sources/gdb-${GDB_VERSION}.tar.gz
fi

cd gdb-${GDB_VERSION}-build
echo "configure gdb"
../gdb-${GDB_VERSION}/configure ${GDB_FLAGS}
echo "build gdb"
make
make install

cd ../..

echo "*****************************************************"
echo "*** build gdb: DONE                               ***"
echo "*****************************************************"

