#!/bin/bash 

#    YAATOBS - yet another arm toolchain build script
# 
#    Copyright (C) 2019  Torsten Brischalle
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/

set -e

. ./00_settings.sh

# installed size in kB
SIZE=$(du -k -s --apparent-size install|awk '{print $1;}')

rm -f *~

# delete old package-files (if available)
rm -rf tmp_package_files/ 

# delete old Debian Packages in source-directory
rm -f *.deb 

# create directories
mkdir tmp_package_files/
mkdir tmp_package_files/DEBIAN/
mkdir tmp_package_files/usr/
mkdir tmp_package_files/usr/local/

# copy files
cp -r install/* tmp_package_files/usr/local/

cp debian_package/control tmp_package_files/DEBIAN/

# change version in control file
sed 's/'REPLACE_GCC_VERSION'/'${GCC_VERSION}'/g' tmp_package_files/DEBIAN/control > tmp_package_files/DEBIAN/control.mod
mv tmp_package_files/DEBIAN/control.mod tmp_package_files/DEBIAN/control

sed 's/'REPLACE_BINUTILS_VERSION'/'${BINUTILS_VERSION}'/g' tmp_package_files/DEBIAN/control > tmp_package_files/DEBIAN/control.mod
mv tmp_package_files/DEBIAN/control.mod tmp_package_files/DEBIAN/control

sed 's/'REPLACE_NEWLIB_VERSION'/'${NEWLIB_VERSION}'/g' tmp_package_files/DEBIAN/control > tmp_package_files/DEBIAN/control.mod
mv tmp_package_files/DEBIAN/control.mod tmp_package_files/DEBIAN/control

sed 's/'REPLACE_GDB_VERSION'/'${GDB_VERSION}'/g' tmp_package_files/DEBIAN/control > tmp_package_files/DEBIAN/control.mod
mv tmp_package_files/DEBIAN/control.mod tmp_package_files/DEBIAN/control

sed 's/'REPLACE_TYPE'/'${TOOLCHAIN_TYPE}'/g' tmp_package_files/DEBIAN/control > tmp_package_files/DEBIAN/control.mod
mv tmp_package_files/DEBIAN/control.mod tmp_package_files/DEBIAN/control

sed 's/'REPLACE_FULL_NAME'/'"${TOOLCHAIN_FULL_NAME}"'/g' tmp_package_files/DEBIAN/control > tmp_package_files/DEBIAN/control.mod
mv tmp_package_files/DEBIAN/control.mod tmp_package_files/DEBIAN/control

# change size in control file
sed 's/'REPLACE_SIZE'/'${SIZE}'/g' tmp_package_files/DEBIAN/control > tmp_package_files/DEBIAN/control.mod
mv tmp_package_files/DEBIAN/control.mod tmp_package_files/DEBIAN/control

# build new package
fakeroot dpkg -b tmp_package_files arm-gcc-${TOOLCHAIN_TYPE}-bri-${GCC_VERSION}-all.deb

# clean up
rm -rf tmp_package_files/
